@@ -1,4 +1,7 @@
+import numpy as np
+
 import pdfstream.callbacks.basic as mod
+from pdfstream.callbacks.composer import gen_stream
 
 
 def test_NumpyExporter(tmpdir, array_stream):
@@ -16,10 +19,13 @@ def test_StackedNumpyExporter(tmpdir, array_stream):
 
 
 def test_StackedNumpyTextExporter(tmpdir, array_stream):
-    cb = mod.StackedNumpyTextExporter(str(tmpdir), file_prefix="{start[sample_name]}_", data_keys=["x0"])
+    cb = mod.StackedNumpyTextExporter("{start[sample_name]}_", str(tmpdir), ["x0", "x1"], ".x")
     for name, doc in array_stream:
         cb(name, doc)
-    assert len(tmpdir.listdir()) > 0
+    files = tmpdir.listdir()
+    assert len(files) > 0
+    arr = np.loadtxt((files[0]))
+    print(arr)
 
 
 def test_DataFrameExporter(tmpdir, array_stream):
@@ -34,3 +40,20 @@ def test_SmartScalarPlot(ymax_stream):
     for name, doc in ymax_stream:
         cb(name, doc)
     cb.show()
+
+
+def test_CalibrationExporter(tmpdir):
+    # case 1
+    start = {}
+    ce = mod.CalibrationExporter(tmpdir)
+    for name, doc in gen_stream([{}], start):
+        ce(name, doc)
+    files = tmpdir.listdir()
+    assert len(files) == 0
+    # case 2
+    start = {"calibration_md": {"distance": 2, "wavelength": 2}}
+    for name, doc in gen_stream([{}], start):
+        ce(name, doc)
+    files = tmpdir.listdir()
+    assert len(files) > 0
+    print(files[0].read_text(encoding="utf-8"))
